# GSy Framework

[![codecov](https://codecov.io/gh/gridsingularity/gsy-framework/branch/master/graph/badge.svg?token=CAYP3OC8P4)](https://codecov.io/gh/gridsingularity/gsy-framework)

Framework that contains utilities and libraries that are used in multiple GSy repos and services. 
